@@ -77,7 +77,7 @@ sub forum_list : Regex('^forum/(\w+)$') {
 
     if ($rss) {
         foreach (@topics) {
-            my $rs = $c->model('DBIC::Comment')->search(
+            my $rs = $c->model('DBIC::Comment')->find(
                 {   object_type => 'topic',
                     object_id   => $_->topic_id,
                 },
@@ -86,7 +86,7 @@ sub forum_list : Regex('^forum/(\w+)$') {
                     page     => 1,
                     columns  => [ 'text', 'formatter' ],
                 }
-            )->first;
+            );
             next unless ($rs);
             $_->{text} = $rs->text;
 
